@@ -3,9 +3,10 @@ from django.contrib import admin
 from django.contrib.auth.admin import UserAdmin
 from django.contrib.auth.forms import UserChangeForm
 
-from chibi_user.models import User
+#from chibi_user.models import User
 
 
+"""
 class User_admin_change_form( UserChangeForm ):
     class Meta( UserChangeForm.Meta ):
         model = User
@@ -16,3 +17,4 @@ class User_admin( UserAdmin ):
 
 
 admin.site.register( User, User_admin )
+"""
