@@ -1,6 +1,6 @@
 from django.test import TestCase
 
-from chibi_user.models import User
+from chibi_user.models.user import User
 
 
 class Test_user( TestCase ):
@@ -16,5 +16,5 @@ class Test_user( TestCase ):
         user_2 = User.objects.create_user(
             username='test_2', password='password', email=None )
         self.assertNotEqual( user.pk, user_2.pk )
-        self.assertIsNone( user.email )
-        self.assertIsNone( user_2.email )
+        self.assertEqual( user.email, '' )
+        self.assertEqual( user_2.email, '' )
